abacusai.chatllm_memory — AbacusAI documentation

# abacusai.chatllm_memory

## Classes

`ChatllmMemory` | An LLM created memory in ChatLLM

## Module Contents

class abacusai.chatllm_memory.ChatllmMemory(client, chatllmMemoryId=None, memory=None, sourceDeploymentConversationId=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An LLM created memory in ChatLLM

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - chatllmMemoryId (str) – The ID of the chatllm memory.

    - memory (str) – The text of the ChatLLM memory.

    - sourceDeploymentConversationId (str) – The deployment conversation where this memory was created.

  chatllm_memory_id = None
  memory = None
  source_deployment_conversation_id = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict